@@ -1,6 +1,6 @@
 package P9Y::ProcessTable;
 
-our $VERSION = '0.95_004'; # VERSION
+our $VERSION = '0.98_01'; # VERSION
 # ABSTRACT: Portably access the process table
 
 # use sanity;
@@ -17,22 +17,22 @@ BEGIN {
     # Figure out which OS module we should use
     my $_os = lc($^O);
     if ( $_os =~ /mswin32|cygwin/ ) {
-        require P9Y::ProcessTable::Win32;
+        require P9Y::ProcessTable::OS::Win32;
     }
     elsif ( $_os eq 'freebsd' ) {
 
         # BSD::Process currently only supports FreeBSD;
         # fall by on /proc for the others
-        require P9Y::ProcessTable::BSD;
+        require P9Y::ProcessTable::OS::BSD;
     }
     elsif ( $_os eq 'darwin' ) {
-        require P9Y::ProcessTable::Darwin;
+        require P9Y::ProcessTable::OS::Darwin;
     }
     elsif ( $_os eq 'os2' ) {
-        require P9Y::ProcessTable::OS2;
+        require P9Y::ProcessTable::OS::OS2;
     }
     elsif ( $_os eq 'vms' ) {
-        require P9Y::ProcessTable::VMS;
+        require P9Y::ProcessTable::OS::VMS;
     }
     elsif ( $_os eq 'dos' ) {
         die "Heh, DOS processes... you're funny!";
@@ -40,7 +40,7 @@ BEGIN {
     else {
         # let's hope they have /proc
         if ( -d dir( '', 'proc' ) ) {
-            require P9Y::ProcessTable::ProcFS;
+            require P9Y::ProcessTable::OS::ProcFS;
         }
         else {
             die "No idea how to handle $_os processes."
@@ -49,29 +49,9 @@ BEGIN {
     }
 }
 
-#############################################################################
-# Common Methods (may potentially be redefined with OS-specific ones)
-
-no warnings 'redefine';
-
-sub table {
-   my $self = shift;
-   return map { $self->process($_) } ($self->list);
-}
-
-sub process {
-   my ($self, $pid) = @_;
-   $pid = $$ if (@_ == 1);
-   my $hash = $self->_process_hash($pid);
-   return unless $hash && $hash->{pid};
-
-   $hash->{_pt_obj} = $self;
-   return P9Y::ProcessTable::Process->new($hash);
-}
-
 42;
 
-
+__END__
 
 =pod
 
@@ -254,6 +234,15 @@ support, dive into the C<<< ProcFS >>> code and submit a patch.
 
 =item *
 
+One would say that the class-based calling of ProcessTable (vs. the more traditional OO model of P9Y:PT:Process) is confusing.  I tend to agree,
+but it was modeled after Proc:PT's calling scheme.
+
+=back
+
+=over
+
+=item *
+
 See L<P9Y::ProcessTable::Process> for other caveats.
 
 =back
@@ -309,28 +298,50 @@ those networks/channels and get help:
 
 irc.perl.org
 
-You can connect to the server at 'irc.perl.org' and join this channel: #win32 then talk to this person for help: SineSwiper.
+You can connect to the server at 'irc.perl.org' and talk to this person for help: SineSwiper.
 
 =back
 
 =head2 Bugs / Feature Requests
 
-Please report any bugs or feature requests via L<L<https://github.com/SineSwiper/P9Y-ProcessTable/issues>|GitHub>.
+Please report any bugs or feature requests via L<https://github.com/SineSwiper/P9Y-ProcessTable/issues>.
 
 =head1 AUTHOR
 
-Brendan Byrd <BBYRD@CPAN.org>
+Brendan Byrd <bbyrd@cpan.org>
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Brendan Byrd <GitHub@ResonatorSoft.org>
+
+=item *
+
+Brendan Byrd <Perl@ResonatorSoft.org>
+
+=item *
+
+Chris 'BinGOs' Williams <chris@bingosnet.co.uk>
+
+=item *
+
+Mithun Ayachit <m0t0rbr3th@gmail.com>
+
+=item *
+
+Mithun Ayachit <mayachit@amfam.com>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Brendan Byrd.
+This software is Copyright (c) 2013 by Brendan Byrd.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
