@@ -1,6 +1,6 @@
 package P9Y::ProcessTable::Process;
 
-our $VERSION = '0.95_004'; # VERSION
+our $VERSION = '0.98_01'; # VERSION
 # ABSTRACT: Base class for a single process
 
 #############################################################################
@@ -127,7 +127,7 @@ around priority => sub {
 
 42;
 
-
+__END__
 
 =pod
 
@@ -253,18 +253,40 @@ site near you, or see L<https://metacpan.org/module/P9Y::ProcessTable/>.
 
 =head1 AUTHOR
 
-Brendan Byrd <BBYRD@CPAN.org>
+Brendan Byrd <bbyrd@cpan.org>
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Brendan Byrd <GitHub@ResonatorSoft.org>
+
+=item *
+
+Brendan Byrd <Perl@ResonatorSoft.org>
+
+=item *
+
+Chris 'BinGOs' Williams <chris@bingosnet.co.uk>
+
+=item *
+
+Mithun Ayachit <m0t0rbr3th@gmail.com>
+
+=item *
+
+Mithun Ayachit <mayachit@amfam.com>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Brendan Byrd.
+This software is Copyright (c) 2013 by Brendan Byrd.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
